@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.13'; # VERSION
+our $DATE = '2015-10-20'; # DATE
+our $VERSION = '0.14'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,6 +10,7 @@ use warnings;
 use App::lcpan::Call qw(call_lcpan_script);
 use Data::Dmp;
 use Dist::Zilla::File::InMemory;
+use ExtUtils::MakeMaker;
 use File::Path qw(make_path);
 use File::Slurper qw(read_binary write_binary);
 use File::Temp qw(tempfile tempdir);
@@ -25,6 +26,7 @@ with (
     },
     'Dist::Zilla::Role::FileGatherer',
     'Dist::Zilla::Role::FileMunger',
+    'Dist::Zilla::Role::MetaProvider',
     'Dist::Zilla::Role::PERLANCAR::WriteModules',
 );
 
@@ -123,9 +125,7 @@ sub munge_script {
 
     #$self->log_debug(["depak result: %s", $depak_res]);
 
-    for (@{ $depak_res->[3]{'func.included_modules'} }) {
-        $self->{_mods}{$_} = 0;
-    }
+    $self->{_mods} = $depak_res->[3]{'func.included_modules'};
 
     # re-add the file instead of changing the content, so we can re-set the
     # encoding to 'bytes'
@@ -140,14 +140,19 @@ sub munge_module {
 
     my $munged;
     my $content = $file->content;
-    if ($content =~ /^#\s*PACKED_MODULES\s*$/m) {
+    my @pod;
+
+    if ($content =~ /^#\s*(PACKED_MODULES|PACKED_CONTENTS_POD)\s*$/m) {
         $munged++;
         $self->{_mods} //= {};
         $content =~ s/(^#\s*PACKED_MODULES\s*$)/
-            "our \@PACKED_MODULES = \@{" . dmp([sort keys %{$self->{_mods}}]) . "}; $1"/em;
+            "our \%PACKED_MODULES = %{ " . dmp($self->{_mods}) . " }; $1"/em;
+        push @pod, "Modules packed into this distribution:\n\n=over\n\n",
+            (map {"=item * $_\n\n"} sort keys %{$self->{_mods}}),
+            "\n=back\n\n";
     }
 
-    if ($content =~ /^#\s*PACKED_DISTS\s*$/m) {
+    if ($content =~ /^#\s*(PACKED_DISTS|PACKED_CONTENTS_POD)\s*$/m) {
         $munged++;
         unless ($self->{_dists}) {
             if (!keys %{ $self->{_mods} }) {
@@ -163,16 +168,39 @@ sub munge_module {
         }
         $content =~ s/(^#\s*PACKED_DISTS\s*$)/
             "our \@PACKED_DISTS = \@{" . dmp([sort keys %{$self->{_dists}}]) . "}; $1"/em;
+        push @pod, "Distributions packed into this distribution:\n\n=over\n\n",
+            (map {"=item * $_\n\n"} sort keys %{$self->{_dists}}),
+            "\n=back\n\n";
+    }
+
+    if ($content =~ /^#\s*PACKED_CONTENTS_POD\s*$/m) {
+        $munged++;
+        $content =~ s/(^#\s*PACKED_CONTENTS_POD\s*$)/
+            join("", @pod)/em;
+        push @pod, "Distributions packed inside this script:\n\n=over\n\n",
+            (map {"=item * $_\n\n"} sort keys %{$self->{_dists}}),
+            "\n=back\n\n";
     }
 
     if ($munged) {
-        $self->log_debug(["Setting \@PACKED_MODULES / \@PACKED_DISTS in %s", $file->{name}]);
+        $self->log_debug(["Setting %PACKED_MODULES / \@PACKED_DISTS / PACKED_CONTENTS_POD in %s", $file->{name}]);
         $file->content($content);
     }
 }
 
 sub gather_files {}
 
+sub metadata {
+    my $self = shift;
+
+    return {
+        x_Dist_Zilla_Plugin_Depak => {
+            packed_modules => $self->{_mods},
+            packed_dists   => $self->{_dists},
+        },
+    };
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 # ABSTRACT: Pack dependencies onto scripts during build using 'depak'
@@ -189,7 +217,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.13 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-27.
+This document describes version 0.14 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-10-20.
 
 =head1 SYNOPSIS
 
@@ -213,7 +241,7 @@ ends in C<::Packed>), which contains:
 
 During build, these will be replaced with:
 
- our @PACKED_MODULES = (...); # PACKED_MODULES
+ our %PACKED_MODULES = (...); # PACKED_MODULES
  our @PACKED_DISTS = (...); # PACKED_DISTS
 
 =head1 DESCRIPTION
@@ -227,13 +255,16 @@ the depak configuration.
 
 In addition to replacing scripts with the packed version, it will also search
 for directives C<# PACKED_MODULES> and C<# PACKED_DISTS> in module files and
-replace them with C<@PACKED_MODULES> and C<@PACKED_DISTS>. The
-C<@PACKED_MODULES> array lists all the modules that are included in the one of
+replace them with C<%PACKED_MODULES> and C<@PACKED_DISTS>. The
+C<%PACKED_MODULES> hash lists all the modules that are included in the one of
 the scripts. This can be useful for tools that might need it. C<@PACKED_DISTS>
 array lists all the dists that are included in one of the scripts. This also can
 be useful for tools that might need it, like
 L<Dist::Zilla::Plugin::PERLANCAR::CheckDepDists>.
 
+There is also C<# PACKED_CONTENTS_POD> which you can put in your script. It will
+be replaced with POD that list the packed modules/dists.
+
 =for Pod::Coverage .+
 
 =head1 CONFIGURATION
